discovery

package
v0.0.0-...-57b3f38 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 28, 2024 License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Overview

Package discovery provides a core business API of a discovery.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CreateContent

func CreateContent(operationType string, disco Discovery) (string, error)

CreateContent creates a message discovery content, this content is encoded in base64.

func ValidateCatalog

func ValidateCatalog(ctx context.Context, cfg shacl.Config, catalog []string) ([]shacl.Validation, error)

ValidateCatalog validates multiple datasets, which collectively form a catalog.

Types

type Discovery

type Discovery struct {
	Dataset string
}

Discovery contains dataset.

func New

func New(dataset []byte) Discovery

New is a factory function to create a Discovery.

Jump to